@@ -1,3 +1,4 @@
+/* vim: set sw=4 ts=4 sts=4 et: */
 #undef NDEBUG
 #define _POSIX_C_SOURCE 200809L
 #include <l4array.h>
@@ -44,5 +45,6 @@ int main () {
     wait (&status);
     assert (WIFEXITED (status) && WEXITSTATUS (status) == 0);
 
+    puts ("test-file => PASS!");
     return 0;
 }
